Class: ActiveSupport::Cache::NullStore

Inherits:
Store
  • Object
show all
Includes:
Strategy::LocalCache
Defined in:
lib/active_support/cache/null_store.rb

Overview

A cache store implementation which doesn’t actually store anything. Useful in development and test environments where you don’t want caching turned on but need to go through the caching interface.

This cache does implement the local cache strategy, so values will actually be cached inside blocks that utilize this strategy. See ActiveSupport::Cache::Strategy::LocalCache for more details.

Instance Method Summary collapse

Instance Method Details

#cleanup(options = nil) ⇒ Object



16
17
# File 'lib/active_support/cache/null_store.rb', line 16

def cleanup(options = nil)
end

#clear(options = nil) ⇒ Object



13
14
# File 'lib/active_support/cache/null_store.rb', line 13

def clear(options = nil)
end

#decrement(name, amount = 1, options = nil) ⇒ Object



22
23
# File 'lib/active_support/cache/null_store.rb', line 22

def decrement(name, amount = 1, options = nil)
end

#delete_matched(matcher, options = nil) ⇒ Object



25
26
# File 'lib/active_support/cache/null_store.rb', line 25

def delete_matched(matcher, options = nil)
end

#increment(name, amount = 1, options = nil) ⇒ Object



19
20
# File 'lib/active_support/cache/null_store.rb', line 19

def increment(name, amount = 1, options = nil)
end